function recon = senserecon(coilimagealias, coilprofile,reduc );
%
%   Use coilprofile to form the encoding matrix and find its inverse.
%   Apply the inverse matrix to the aliased image data to recover
%   the original image. Repeat this process for each pixel.
%
%   Input:
%   coilimagealias :  matrices of aliased images
%   coilprofile    :  coil sensitivity maps
%   reduc          :  reduction factor
%
%   Output:
%   recon          :  reconstructed image
%


coiln = size(coilprofile,3);
FOV = size(coilimagealias,1);

recon = zeros(FOV);
for y = 1:FOV/reduc
    for x = 1:FOV
        for m = 1:coiln
            for n = 1:reduc
                phase = mod((FOV/2-FOV/reduc/2)+y+(n-1)*(FOV/reduc),FOV);
                if phase == 0
                    phase = FOV;
                end
                a(m,1) = coilimagealias((FOV/2-FOV/reduc/2)+y,x,m);
                encode(m,n) = coilprofile(phase,x,m);
            end
        end
        b = pinv(encode)*a;
        for n = 1:reduc
            phase = mod((FOV/2-FOV/reduc/2)+y+(n-1)*(FOV/reduc),FOV);
            if phase == 0
                phase = FOV;
            end
            recon(phase,x) = b(n,1);
        end
    end
end